@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -90,6 +90,8 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
 
     private boolean smtpEnvelopeFrom;
 
+    private boolean sendPartial;
+
     private String smtpAuthEnc;
 
     private int smtpTimeout;
@@ -128,6 +130,12 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
             logBuilder.append("\tSMTP Authentication: ").append(smtpAuth).append('\n');
         }
 
+        {
+            final String sendPartialStr = configuration.getProperty("com.openexchange.smtp.sendPartial", "false").trim();
+            sendPartial = Boolean.parseBoolean(sendPartialStr);
+            logBuilder.append("\tSend Partial: ").append(sendPartial).append('\n');
+        }
+
         {
             final String smtpEnvFromStr = configuration.getProperty("com.openexchange.smtp.setSMTPEnvelopeFrom", "false").trim();
             smtpEnvelopeFrom = Boolean.parseBoolean(smtpEnvFromStr);
@@ -194,6 +202,7 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
     @Override
     protected void resetFields() {
         smtpLocalhost = null;
+        sendPartial = false;
         smtpAuth = false;
         smtpEnvelopeFrom = false;
         smtpAuthEnc = null;
@@ -214,6 +223,11 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
         return smtpAuth;
     }
 
+    @Override
+    public boolean isSendPartial() {
+        return sendPartial;
+    }
+
     @Override
     public boolean isSmtpEnvelopeFrom() {
         return smtpEnvelopeFrom;
@@ -244,6 +258,16 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
         return transportProperties.getReferencedPartLimit();
     }
 
+    @Override
+    public boolean isEnforceSecureConnection() {
+        return transportProperties.isEnforceSecureConnection();
+    }
+
+    @Override
+    public void setEnforceSecureConnection(boolean enforceSecureConnection) {
+        transportProperties.setEnforceSecureConnection(enforceSecureConnection);
+    }
+
     @Override
     public String getSSLProtocols() {
         return sslProtocols;
