@@ -58,6 +58,7 @@ import com.openexchange.config.Reloadable;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.context.ContextService;
 import com.openexchange.groupware.notify.hostname.HostnameService;
+import com.openexchange.log.audit.AuditLogService;
 import com.openexchange.mail.transport.TransportProvider;
 import com.openexchange.mail.transport.config.NoReplyConfigFactory;
 import com.openexchange.mail.transport.listener.MailTransportListener;
@@ -103,6 +104,7 @@ public final class SMTPActivator extends HousekeepingActivator {
 
             trackService(HostnameService.class);
             trackService(NoReplyConfigFactory.class);
+            trackService(AuditLogService.class);
             track(MailcapCommandMap.class, new MailcapServiceTracker(context));
             openTrackers();
 
